Request

Struct Request 

#[repr(C)]
pub struct Request { pub ping_tx_time: Instant, pub ping_reply_time: Duration, pub request_tx_time: Instant, }
Ranging request message

This message is typically sent in response to a ranging ping, to request a ranging response. See module documentation for more info.

Fields

ping_tx_time: Instant

When the original ping was sent, in local time on the anchor

ping_reply_time: Duration

The time between the ping being received and the reply being sent

request_tx_time: Instant

When the ranging request was sent, in local sender time

Implementations

Source

impl Request

pub fn new<SPI, CS>( dw1000: &mut DW1000<SPI, CS, Ready>, ping: &RxMessage<Ping>, ) -> Result<TxMessage<Self>, Error<SPI, CS>>
where SPI: Transfer<u8> + Write<u8>, CS: OutputPin,

Creates a new ranging request message

Only creates the message, but doesn’t yet send it. Sets the transmission time to 10 milliseconds in the future. Make sure to send the message within that time frame, or the distance measurement will be negatively affected.